#
# spec file for package mate-common
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define _version 1.28

Name:           mate-common
Version:        1.28.0
Release:        1.2
Summary:        Common scripts and macros to develop with MATE
License:        GPL-3.0-or-later
URL:            https://mate-desktop.org/
Group:          Development/Tools/Building
Source:         https://pub.mate-desktop.org/releases/%{_version}/%{name}-%{version}.tar.xz
BuildRequires:  autoconf
BuildRequires:  automake
# Upstream source distribution requires execution of 'autogen.sh';
# mate-common is a requirement, while this doesn't change we pull
# all the necessary stuff from here so we won't polute other specs.
Requires:       autoconf
Requires:       autoconf-archive
Requires:       automake
Requires:       gettext
Requires:       libtool
Requires:       pkgconfig
Requires:       pkgconfig(glib-2.0)
Requires:       pkgconfig(gtk-doc)
BuildArch:      noarch

%description
mate-common is an extension to autoconf, automake and libtool for the MATE
desktop environment and MATE applications. mate-autogen, and several macros are
included to help in MATE source trees.

%prep
%autosetup -p1

%build
%configure
%make_build

%install
%make_install

%files
%license COPYING
%doc AUTHORS ChangeLog NEWS
%{_bindir}/mate-doc-common
%{_bindir}/mate-autogen
%{_datadir}/aclocal/mate-code-coverage.m4
%{_datadir}/aclocal/mate-common.m4
%{_datadir}/aclocal/mate-compiler-flags.m4
%{_datadir}/mate-common/
%{_mandir}/man?/mate-autogen.?%{?ext_man}
%{_mandir}/man?/mate-doc-common.?%{?ext_man}

%changelog
* Sat Mar 23 2024 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.28.0
  * Add meson compilation support
  * ci: use ubuntu jammy as docker
* Tue Aug 10 2021 Hillwood Yang <hillwood@opensuse.org>
- Update version to 1.26.0
  * Upstream does not provide changelog
* Sun Aug 16 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.2:
  * mate-compiler-flags: Add -Wno-unused-parameter to maximise C++
    warnings.
  * mate-compiler-flags: Disable -Wno-unused and -Wno-sign-compare.
* Thu Apr  2 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.1:
  * Silent -Wunused-parameter for maximum warning level.
* Wed Feb 26 2020 Alexei Sorokin <sor.alexei@meowr.ru>
- Update to version 1.24.0 (changes since 1.22.0):
  * Update mate-compiler-flags macro.
  * Check if AX_APPEND_FLAG and AX_CHECK_COMPILE_FLAG are available.
  * Set compiler debug flags in MATE_DEBUG_CHECK.
  * Update MATE_CXX_WARNINGS macro.
- Require autoconf-archive.
- Do not require intltool.
- Drop support for old openSUSE versions.
* Tue Mar  5 2019 sor.alexei@meowr.ru
- Update to version 1.22.0:
  * No changelog available.
* Fri Mar  9 2018 sor.alexei@meowr.ru
- Update to version 1.20.0:
  * No changelog available.
* Tue Mar 14 2017 sor.alexei@meowr.ru
- Update to version 1.18.0:
  * NEWS: Use consistent, project wide, markdown-like formatting to
    make generating release announcements easier.
* Tue Sep 20 2016 sor.alexei@meowr.ru
- Update to version 1.16.0:
  * Check only for autoreconf in mate-autogen as autoconf,
    automake, libtool, gettext are already checked by autoreconf.
* Sat Apr  9 2016 sor.alexei@meowr.ru
- Update to version 1.14.0.
* Mon Jan 25 2016 sor.alexei@meowr.ru
- Update to version 1.13.0:
  * Remove references to obsolete MATE components.
* Thu Nov  5 2015 sor.alexei@meowr.ru
- Update to 1.12.0.
* Tue Oct 20 2015 sor.alexei@meowr.ru
- Update to 1.11.0:
  * Support lcov 1.12.
  * Update docs and example script.
- Require intltool 0.50.1.
* Tue Apr 14 2015 p.drouand@gmail.com
- Update to version 1.10.0
  * Add support for automake 1.15
* Mon Mar 23 2015 p.drouand@gmail.com
- Update to version 1.9.90 (unstable)
  * Add support for automake 1.15
* Tue Jan 13 2015 p.drouand@gmail.com
- Update to version 1.9.1 (unstable)
  + mate-autogen.sh: run glib-gettexize if using GLib gettext
  + mate-autogen: Check for appdata-xml.m4 with APPDATA_XML
  + mate-autogen.sh: correct IFS value
    Due to a likely copy-paste mistake, the default value of IFS
    was being set to 9 spaces instead of a tab and a space.
  + mate-autogen: Fix check if stdin is a tty
  + mate-autogen: make program_VERSION a local variable
    Otherwise we may end up overriding what was manually set in the
    environment.
  + code-coverage: Support lcov 1.11
* Sun Jul 13 2014 p.drouand@gmail.com
- Update to version 1.9.0 (unstable)
  + no changes since version 1.8.0
* Wed Mar  5 2014 p.drouand@gmail.com
- Update to version 1.8.0
  + no changes since version 1.7.90
* Sat Feb 15 2014 p.drouand@gmail.com
- Update to version 1.7.90 (unstable)
  + configure: Add check-news
- Use download Url as source
- Remove useless xz require
* Mon Feb 10 2014 p.drouand@gmail.com
- Update to version 1.7.3 (unstable)
  + fix tty detection for terminal codes.
* Sun Jan 19 2014 p.drouand@gmail.com
- Update to version 1.7.2 (unstable)
  + many fixes from gnome-common that are useful for MATE
  + Read the dirlist file unconditionally
  + Better support of using AUTOCONF environment variable
    bgo #510713 (http://bugzilla.gnome.org/show_bug.cgi?id=510713)
  + trace AC_CONFIG_SUBDIRS with autoconf
    Find configure.ac and configure.in files using the trace
    functionality of autoconf in order to skip build directories from
    incomplete make distcheck runs.
    bgo #510713 (http://bugzilla.gnome.org/show_bug.cgi?id=510713)
  + check for glibtoolize in gnome-autogen.sh
    bgo #564558 (http://bugzilla.gnome.org/show_bug.cgi?id=564558)
  + Fix srcdir!=builddir for Scrollkeeper
    bgo #315320 (http://bugzilla.gnome.org/show_bug.cgi?id=315320)
    bgo #409060 (http://bugzilla.gnome.org/show_bug.cgi?id=409060)
    bgo #685388 (http://bugzilla.gnome.org/show_bug.cgi?id=685388)
  + mate-autogen: Don't print terminal codes if stdin isn't a tty
    Otherwise this shows up as garbage in log files.
  + fix bashisms in mate-autogen
  + macros/mate-autogen: Create m4 directory if it doesnt exits
    This is a automake bug fixed in automake 1.13.2
  + mate-autogen.sh: Use autoreconf instead
    autopoint/libtoolize/autoconf/automake manually
  + Replace deprecated AC_HELP_STRING with AS_HELP_STRING
* Fri Jan 17 2014 p.drouand@gmail.com
- Update to version 1.7.1 (unstable)
  + Replace mate-doc-utils with yelp-tools
- Changes from version 1.7.0
  + Automake turned 14 on Arch Linux
* Fri Sep 20 2013 cfarrell@suse.com
- license update: GPL-3.0+
  No indication of GPL-3.0 only files.
* Wed Sep 11 2013 p.drouand@gmail.com
- Update to version 1.6.2
  + automake turned 14 on Arch Linux
* Sun May 12 2013 p.drouand@gmail.com
- Update to version 1.6.1
  + switch to make dist
* Wed Apr  3 2013 johann.luce@wanadoo.fr
- Update to version 1.6.0
  + No changelog available
* Thu Mar 14 2013 p.drouand@gmail.com
- Update to version 1.5.2:
  + Add GPL3 copyright headers
  + Rename configure.in to configure.ac to be liked by autoconf >= 1.12
    Fix warning: autoconf input should be named 'configure.ac', not 'configure.in'
* Thu Jan 24 2013 nmo.marques@gmail.com
- Update to version 1.5.1
  + fix coalitions with gnome packages
* Fri Dec 14 2012 stefano-k@mate-desktop.org
- Checking OBS, triggering rebuild
* Mon Nov 19 2012 nmo.marques@gmail.com
- Add xz to BRs, reverting otherwise build in 12.1 is broken
* Sun Nov 18 2012 nmarques@mate-desktop.org
- Remove %%clean and xz BRs; update contact in RPM changelog and
  minor spec cleansings.
* Thu Oct  4 2012 nmarques@mate-desktop.org
- Update to version 1.5.0
  + bump release, no changes
* Tue Oct  2 2012 nmarques@mate-desktop.org
- Remove mate-doc-utils from Requires because of cyclic dependency
* Fri Sep 21 2012 nmarques@mate-desktop.org
- Rework on spec for review
* Thu Sep 13 2012 nmarques@mate-desktop.org
- Add mate-doc-utils to requires; this is currently needed for all
  packages for autogen.sh
* Sat Sep  8 2012 nmarques@mate-desktop.org
- Copypac to X11:MATE
  + minor cosmetic fixes
* Sat Jul 14 2012 nmarques@mate-desktop.org
- Update to version 1.4.0
* Sun Jun 17 2012 nmarques@mate-desktop.org
- Update to version 1.3.0
* Sat Jun 16 2012 nmarques@mate-desktop.org
- Initial package from 1.2.2 release
